@@ -260,20 +260,20 @@ sub parse {
 
     # Perl line
     if ($state eq 'text' && $line !~ s/^(\s*)$start$replace/$1$raw_start/) {
-      if ($state eq 'text' && $line =~ s/^(\s*)$start($expr)?(.*)$//) {
-        $line = $2 ? "$1$raw_tag_start$2$3 " : "$raw_tag_start$3 $raw_trim";
-        $line .= $raw_tag_end;
-      }
+      $line =~ s/^(\s*)$start($expr)?// and $line =
+        $2
+        ? "$1$raw_tag_start$2$line $raw_tag_end"
+        : "$raw_tag_start$line $raw_trim$raw_tag_end";
     }
 
     # Escaped line ending
     if ($line =~ /(\\+)$/) {
       my $len = length $1;
 
-      # Escaped newline
+      # Newline
       if ($len == 1) { $line =~ s/\\$// }
 
-      # Escaped backslash
+      # Backslash
       if ($len >= 2) {
         $line =~ s/\\\\$/\\/;
         $line .= "\n";
@@ -447,7 +447,7 @@ __END__
 
 =head1 NAME
 
-Mojo::Template - Perlish Templates!
+Mojo::Template - Perl-ish Templates!
 
 =head1 SYNOPSIS
 
@@ -483,27 +483,24 @@ projects.
 Like preprocessing a config file, generating text from heredocs and stuff
 like that.
 
-  <% Inline Perl %>
+  <% Perl code %>
   <%= Perl expression, replaced with result %>
   <%== Perl expression, replaced with XML escaped result %>
   <%# Comment, useful for debugging %>
   <%% Replaced with "<%", useful for generating templates %>
-  % Perl line
-  %= Perl expression line, replaced with result
-  %== Perl expression line, replaced with XML escaped result
-  %# Comment line, useful for debugging
+  % Perl code line, treated as "<% line =%>"
+  %= Perl expression line, treated as "<%= line %>"
+  %== Perl expression line, treated as "<%== line %>"
+  %# Comment line, treated as "<%# line =%>"
   %% Replaced with "%", useful for generating templates
 
 =head2 Automatic Escaping
 
-Automatic escaping behavior can be reversed with the C<auto_escape>
-attribute, this is the default in L<Mojolicious> C<.ep> templates for
-example.
+Escaping behavior can be reversed with the C<auto_escape> attribute, this is
+the default in L<Mojolicious> C<.ep> templates for example.
 
   <%= Perl expression, replaced with XML escaped result %>
   <%== Perl expression, replaced with result %>
-  %= Perl expression line, replaced with XML escaped result
-  %== Perl expression line, replaced with result
 
 L<Mojo::ByteStream> objects are always excluded from automatic escaping.
 
@@ -527,7 +524,7 @@ C<end> keywords.
   <%= $block->('Baerbel') %>
   <%= $block->('Wolfgang') %>
 
-=head2 Indenting
+=head2 Indentation
 
 Perl lines can also be indented freely.
 
